@@ -3,18 +3,33 @@ from ...db.sa import sa
 
 ##__________________________________________________________________||
 class TypeFieldAssociation(sa.Model):
+    """Many-to-many relation between ProductType and Field
+
+
+    This class defines which fields each product type has.
+
+    When a product type is deleted, all related instances of this
+    class will be automatically deleted ("delete-orphan").
+
+
+    On the other hand, a field is not allowed to be deleted if it is
+    related to an instances of this class (as field_id is not
+    nullable while "delete-orphan" is not used on field).
+
+    """
+
     __tablename__ = "type_field_association"
+    iid = sa.Column(sa.Integer(), primary_key=True)
+    order = sa.Column(sa.Integer())
     type_id = sa.Column(
-        #
         sa.Integer(),
         sa.ForeignKey("product_types.type_id"),
-        primary_key=True,
+        nullable=False,
     )
     field_id = sa.Column(
-        #
         sa.Integer(),
         sa.ForeignKey("field.field_id"),
-        primary_key=True,
+        nullable=False,
     )
     type_ = sa.relationship(
         "ProductType",
@@ -25,6 +40,10 @@ class TypeFieldAssociation(sa.Model):
         backref=sa.backref("entry_types"),
     )
 
+    __table_args__ = (
+        sa.UniqueConstraint("type_id", "field_id", name="_type_field"),
+    )
+
     def __repr__(self):
         return f"<{self.__class__.__name__} {self.type_name!r} {self.field_name!r}>"
 
