@@ -10,6 +10,7 @@ from .product import (  # noqa: F401
     create_product,
     update_product,
     delete_product,
+    convert_product_type,
 )
 from .product_type import (  # noqa: F401
     create_product_type,
@@ -40,3 +41,6 @@ from .log import (  # noqa: F401
     create_log,
     delete_log,
 )
+from .web_config import (  # noqa: F401
+    save_web_config,
+)
