@@ -14,66 +14,66 @@ snapshots['test_export_db_to_csv_files 1'] = {
     ],
     'attribute_date': [
         {
-            'attribute_id': 1,
             'field_id': 3,
-            'name': 'date_produced',
+            'iid': 1,
             'product_id': 1001,
+            'type_field_association_iid': 3,
             'value': GenericRepr('datetime.date(2019, 2, 13)')
         },
         {
-            'attribute_id': 2,
             'field_id': 3,
-            'name': 'date_produced',
+            'iid': 2,
             'product_id': 1002,
+            'type_field_association_iid': 9,
             'value': GenericRepr('datetime.date(2019, 3, 15)')
         },
         {
-            'attribute_id': 3,
             'field_id': 3,
-            'name': 'date_produced',
+            'iid': 3,
             'product_id': 1010,
+            'type_field_association_iid': 6,
             'value': GenericRepr('datetime.date(2018, 1, 1)')
         },
         {
-            'attribute_id': 4,
             'field_id': 3,
-            'name': 'date_produced',
+            'iid': 4,
             'product_id': 1012,
+            'type_field_association_iid': 3,
             'value': GenericRepr('datetime.date(2020, 1, 20)')
         },
         {
-            'attribute_id': 5,
             'field_id': 3,
-            'name': 'date_produced',
+            'iid': 5,
             'product_id': 1013,
+            'type_field_association_iid': 3,
             'value': GenericRepr('datetime.date(2020, 2, 1)')
         },
         {
-            'attribute_id': 6,
             'field_id': 3,
-            'name': 'date_produced',
+            'iid': 6,
             'product_id': 1070,
+            'type_field_association_iid': 6,
             'value': GenericRepr('datetime.date(2019, 3, 4)')
         },
         {
-            'attribute_id': 7,
             'field_id': 3,
-            'name': 'date_produced',
+            'iid': 7,
             'product_id': 1120,
+            'type_field_association_iid': 6,
             'value': GenericRepr('datetime.date(2019, 6, 7)')
         },
         {
-            'attribute_id': 8,
             'field_id': 3,
-            'name': 'date_produced',
+            'iid': 8,
             'product_id': 1130,
+            'type_field_association_iid': 6,
             'value': GenericRepr('datetime.date(2020, 1, 23)')
         },
         {
-            'attribute_id': 9,
             'field_id': 3,
-            'name': 'date_produced',
+            'iid': 9,
             'product_id': 1150,
+            'type_field_association_iid': 6,
             'value': GenericRepr('datetime.date(2020, 2, 7)')
         }
     ],
@@ -87,129 +87,129 @@ snapshots['test_export_db_to_csv_files 1'] = {
     ],
     'attribute_unicode_text': [
         {
-            'attribute_id': 2,
             'field_id': 1,
-            'name': 'contact',
+            'iid': 2,
             'product_id': 1001,
+            'type_field_association_iid': 1,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 3,
             'field_id': 2,
-            'name': 'produced_by',
+            'iid': 3,
             'product_id': 1001,
+            'type_field_association_iid': 2,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 8,
             'field_id': 1,
-            'name': 'contact',
+            'iid': 8,
             'product_id': 1002,
+            'type_field_association_iid': 7,
             'value': 'abc-def'
         },
         {
-            'attribute_id': 9,
             'field_id': 2,
-            'name': 'produced_by',
+            'iid': 9,
             'product_id': 1002,
+            'type_field_association_iid': 8,
             'value': 'abc-def'
         },
         {
-            'attribute_id': 14,
             'field_id': 1,
-            'name': 'contact',
+            'iid': 14,
             'product_id': 1010,
+            'type_field_association_iid': 4,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 15,
             'field_id': 2,
-            'name': 'produced_by',
+            'iid': 15,
             'product_id': 1010,
+            'type_field_association_iid': 5,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 20,
             'field_id': 1,
-            'name': 'contact',
+            'iid': 20,
             'product_id': 1012,
+            'type_field_association_iid': 1,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 21,
             'field_id': 2,
-            'name': 'produced_by',
+            'iid': 21,
             'product_id': 1012,
+            'type_field_association_iid': 2,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 26,
             'field_id': 1,
-            'name': 'contact',
+            'iid': 26,
             'product_id': 1013,
+            'type_field_association_iid': 1,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 27,
             'field_id': 2,
-            'name': 'produced_by',
+            'iid': 27,
             'product_id': 1013,
+            'type_field_association_iid': 2,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 32,
             'field_id': 1,
-            'name': 'contact',
+            'iid': 32,
             'product_id': 1070,
+            'type_field_association_iid': 4,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 33,
             'field_id': 2,
-            'name': 'produced_by',
+            'iid': 33,
             'product_id': 1070,
+            'type_field_association_iid': 5,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 38,
             'field_id': 1,
-            'name': 'contact',
+            'iid': 38,
             'product_id': 1120,
+            'type_field_association_iid': 4,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 39,
             'field_id': 2,
-            'name': 'produced_by',
+            'iid': 39,
             'product_id': 1120,
+            'type_field_association_iid': 5,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 44,
             'field_id': 1,
-            'name': 'contact',
+            'iid': 44,
             'product_id': 1130,
+            'type_field_association_iid': 4,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 45,
             'field_id': 2,
-            'name': 'produced_by',
+            'iid': 45,
             'product_id': 1130,
+            'type_field_association_iid': 5,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 50,
             'field_id': 1,
-            'name': 'contact',
+            'iid': 50,
             'product_id': 1150,
+            'type_field_association_iid': 4,
             'value': 'pwg-pmn'
         },
         {
-            'attribute_id': 51,
             'field_id': 2,
-            'name': 'produced_by',
+            'iid': 51,
             'product_id': 1150,
+            'type_field_association_iid': 5,
             'value': 'pwg-pmn'
         }
     ],
@@ -450,204 +450,178 @@ snapshots['test_export_db_to_csv_files 1'] = {
     ],
     'products': [
         {
-            'contact': 'pwg-pmn',
-            'date_produced': GenericRepr('datetime.date(2019, 2, 13)'),
             'name': 'lat20190213',
             'note': '''- This is a dummy test with a lat map
 - This should not depend on any beam''',
-            'posted_by': 'pwg-pmn',
             'posting_git_hub_user_id': 1,
-            'produced_by': 'pwg-pmn',
             'product_id': 1001,
             'time_posted': GenericRepr('datetime.datetime(2019, 2, 13, 10, 5, 23)'),
-            'time_updated': GenericRepr('datetime.datetime(2019, 2, 13, 16, 45, 30)'),
+            'time_updated': None,
             'type_id': 1,
-            'updated_by': 'pwg-pmn',
             'updating_git_hub_user_id': 2
         },
         {
-            'contact': 'abc-def',
-            'date_produced': GenericRepr('datetime.date(2019, 3, 15)'),
             'name': 'xyz-s1234-20200101',
             'note': '''- note 1
 - note 2''',
-            'posted_by': 'abc-def',
             'posting_git_hub_user_id': 1,
-            'produced_by': 'abc-def',
             'product_id': 1002,
             'time_posted': GenericRepr('datetime.datetime(2019, 3, 15, 9, 11, 25)'),
             'time_updated': None,
             'type_id': 3,
-            'updated_by': '',
             'updating_git_hub_user_id': None
         },
         {
-            'contact': 'pwg-pmn',
-            'date_produced': GenericRepr('datetime.date(2018, 1, 1)'),
             'name': '20180101',
             'note': '- test entry',
-            'posted_by': 'pwg-pmn',
             'posting_git_hub_user_id': 1,
-            'produced_by': 'pwg-pmn',
             'product_id': 1010,
             'time_posted': GenericRepr('datetime.datetime(2018, 1, 1, 15, 32, 10)'),
             'time_updated': None,
             'type_id': 2,
-            'updated_by': '',
             'updating_git_hub_user_id': None
         },
         {
-            'contact': 'pwg-pmn',
-            'date_produced': GenericRepr('datetime.date(2020, 1, 20)'),
             'name': 'lat20200120',
             'note': '''- This is a dummy test with a lat map
 - A beam depends on this map''',
-            'posted_by': 'pwg-pmn',
             'posting_git_hub_user_id': 1,
-            'produced_by': 'pwg-pmn',
             'product_id': 1012,
             'time_posted': GenericRepr('datetime.datetime(2020, 1, 20, 18, 10, 5)'),
-            'time_updated': GenericRepr('datetime.datetime(2020, 1, 20, 21, 52, 32)'),
+            'time_updated': None,
             'type_id': 1,
-            'updated_by': 'pwg-pmn',
             'updating_git_hub_user_id': 2
         },
         {
-            'contact': 'pwg-pmn',
-            'date_produced': GenericRepr('datetime.date(2020, 2, 1)'),
             'name': 'lat20200201',
             'note': '''- This is a dummy test with a lat map
 - A beam depends on this map''',
-            'posted_by': 'pwg-pmn',
             'posting_git_hub_user_id': 1,
-            'produced_by': 'pwg-pmn',
             'product_id': 1013,
             'time_posted': GenericRepr('datetime.datetime(2020, 2, 1, 11, 5, 2)'),
-            'time_updated': GenericRepr('datetime.datetime(2020, 2, 1, 19, 2, 15)'),
+            'time_updated': None,
             'type_id': 1,
-            'updated_by': 'pwg-pmn',
             'updating_git_hub_user_id': 2
         },
         {
-            'contact': 'pwg-pmn',
-            'date_produced': GenericRepr('datetime.date(2019, 3, 4)'),
             'name': '20190304',
             'note': '- test entry',
-            'posted_by': 'pwg-pmn',
             'posting_git_hub_user_id': 1,
-            'produced_by': 'pwg-pmn',
             'product_id': 1070,
             'time_posted': GenericRepr('datetime.datetime(2019, 3, 4, 8, 12, 41)'),
             'time_updated': None,
             'type_id': 2,
-            'updated_by': '',
             'updating_git_hub_user_id': None
         },
         {
-            'contact': 'pwg-pmn',
-            'date_produced': GenericRepr('datetime.date(2019, 6, 7)'),
             'name': '20190607',
             'note': '- test entry',
-            'posted_by': 'pwg-pmn',
             'posting_git_hub_user_id': 1,
-            'produced_by': 'pwg-pmn',
             'product_id': 1120,
             'time_posted': GenericRepr('datetime.datetime(2019, 6, 7, 18, 21, 21)'),
             'time_updated': None,
             'type_id': 2,
-            'updated_by': '',
             'updating_git_hub_user_id': None
         },
         {
-            'contact': 'pwg-pmn',
-            'date_produced': GenericRepr('datetime.date(2020, 1, 23)'),
             'name': '20200123',
             'note': '- test entry',
-            'posted_by': 'pwg-pmn',
             'posting_git_hub_user_id': 1,
-            'produced_by': 'pwg-pmn',
             'product_id': 1130,
             'time_posted': GenericRepr('datetime.datetime(2020, 1, 23, 12, 11, 45)'),
             'time_updated': None,
             'type_id': 2,
-            'updated_by': '',
             'updating_git_hub_user_id': None
         },
         {
-            'contact': 'pwg-pmn',
-            'date_produced': GenericRepr('datetime.date(2020, 2, 7)'),
             'name': '20200207',
             'note': '- test entry',
-            'posted_by': 'pwg-pmn',
             'posting_git_hub_user_id': 1,
-            'produced_by': 'pwg-pmn',
             'product_id': 1150,
             'time_posted': GenericRepr('datetime.datetime(2020, 2, 7, 9, 42, 11)'),
             'time_updated': None,
             'type_id': 2,
-            'updated_by': '',
             'updating_git_hub_user_id': None
         }
     ],
     'type_field_association': [
         {
             'field_id': 1,
+            'iid': 1,
+            'order': None,
             'type_id': 1
         },
         {
             'field_id': 2,
+            'iid': 2,
+            'order': None,
             'type_id': 1
         },
         {
             'field_id': 3,
+            'iid': 3,
+            'order': None,
             'type_id': 1
         },
         {
             'field_id': 1,
+            'iid': 4,
+            'order': None,
             'type_id': 2
         },
         {
             'field_id': 2,
+            'iid': 5,
+            'order': None,
             'type_id': 2
         },
         {
             'field_id': 3,
+            'iid': 6,
+            'order': None,
             'type_id': 2
         },
         {
             'field_id': 1,
+            'iid': 7,
+            'order': None,
             'type_id': 3
         },
         {
             'field_id': 2,
+            'iid': 8,
+            'order': None,
             'type_id': 3
         },
         {
             'field_id': 3,
+            'iid': 9,
+            'order': None,
             'type_id': 3
         },
         {
             'field_id': 1,
+            'iid': 10,
+            'order': None,
             'type_id': 4
         },
         {
             'field_id': 2,
+            'iid': 11,
+            'order': None,
             'type_id': 4
         },
         {
             'field_id': 3,
+            'iid': 12,
+            'order': None,
             'type_id': 4
         }
     ],
     'web_config': [
         {
-            'config_id': 1,
-            'devtool_loadingstate': True,
-            'head_title': 'Product DB (test)',
-            'product_creation_dialog': True,
-            'product_deletion_dialog': False,
-            'product_update_dialog': True,
-            'toolbar_title': 'Product DB (test)'
+            'id_': 1,
+            'json': '{"headTitle": "Product DB (test)", "toolbarTitle": "Product DB (test)", "devtoolLoadingstate": true, "productCreationDialog": false, "productUpdateDialog": true, "productDeletionDialog": false}'
         }
     ]
 }
