@@ -344,7 +344,12 @@ snapshots['test_schema_success[create] 1'] = {
                                     'name': 'date_produced',
                                     'type_': 'DATE'
                                 },
-                                'name': 'date_produced',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'date_produced',
+                                        'type_': 'DATE'
+                                    }
+                                },
                                 'value': '2020-02-20'
                             }
                         }
@@ -374,7 +379,12 @@ snapshots['test_schema_success[create] 1'] = {
                                     'name': 'contact',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'contact',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'contact',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': 'contact-person'
                             }
                         },
@@ -384,14 +394,17 @@ snapshots['test_schema_success[create] 1'] = {
                                     'name': 'produced_by',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'produced_by',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'produced_by',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': 'producer'
                             }
                         }
                     ]
                 },
-                'contact': 'contact-person',
-                'dateProduced': '2020-02-20',
                 'name': 'beam111',
                 'note': '- Item 1',
                 'paths': {
@@ -412,11 +425,9 @@ snapshots['test_schema_success[create] 1'] = {
                         }
                     ]
                 },
-                'postedBy': 'poster',
                 'postingGitHubUser': {
                     'login': 'user1'
                 },
-                'producedBy': 'producer',
                 'productId': '6',
                 'relations': {
                     'edges': [
@@ -487,7 +498,6 @@ snapshots['test_schema_success[create] 1'] = {
                     'name': 'beam',
                     'typeId': '2'
                 },
-                'updatedBy': None,
                 'updatingGitHubUser': None
             }
         }
@@ -738,7 +748,12 @@ snapshots['test_schema_success[minimum] 1'] = {
                                     'name': 'date_produced',
                                     'type_': 'DATE'
                                 },
-                                'name': 'date_produced',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'date_produced',
+                                        'type_': 'DATE'
+                                    }
+                                },
                                 'value': None
                             }
                         }
@@ -768,7 +783,12 @@ snapshots['test_schema_success[minimum] 1'] = {
                                     'name': 'contact',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'contact',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'contact',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': None
                             }
                         },
@@ -778,25 +798,26 @@ snapshots['test_schema_success[minimum] 1'] = {
                                     'name': 'produced_by',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'produced_by',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'produced_by',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': None
                             }
                         }
                     ]
                 },
-                'contact': None,
-                'dateProduced': None,
                 'name': 'product1',
                 'note': None,
                 'paths': {
                     'edges': [
                     ]
                 },
-                'postedBy': None,
                 'postingGitHubUser': {
                     'login': 'user1'
                 },
-                'producedBy': None,
                 'productId': '6',
                 'relations': {
                     'edges': [
@@ -809,7 +830,6 @@ snapshots['test_schema_success[minimum] 1'] = {
                     'name': 'map',
                     'typeId': '1'
                 },
-                'updatedBy': None,
                 'updatingGitHubUser': None
             }
         }
@@ -998,7 +1018,12 @@ snapshots['test_schema_success[the-same-name-different-type] 1'] = {
                                     'name': 'date_produced',
                                     'type_': 'DATE'
                                 },
-                                'name': 'date_produced',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'date_produced',
+                                        'type_': 'DATE'
+                                    }
+                                },
                                 'value': None
                             }
                         }
@@ -1028,7 +1053,12 @@ snapshots['test_schema_success[the-same-name-different-type] 1'] = {
                                     'name': 'contact',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'contact',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'contact',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': 'contact-person'
                             }
                         },
@@ -1038,14 +1068,17 @@ snapshots['test_schema_success[the-same-name-different-type] 1'] = {
                                     'name': 'produced_by',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'produced_by',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'produced_by',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': 'pwg-pmn'
                             }
                         }
                     ]
                 },
-                'contact': 'contact-person',
-                'dateProduced': None,
                 'name': 'map1',
                 'note': None,
                 'paths': {
@@ -1066,11 +1099,9 @@ snapshots['test_schema_success[the-same-name-different-type] 1'] = {
                         }
                     ]
                 },
-                'postedBy': None,
                 'postingGitHubUser': {
                     'login': 'user1'
                 },
-                'producedBy': 'pwg-pmn',
                 'productId': '6',
                 'relations': {
                     'edges': [
@@ -1083,7 +1114,6 @@ snapshots['test_schema_success[the-same-name-different-type] 1'] = {
                     'name': 'beam',
                     'typeId': '2'
                 },
-                'updatedBy': None,
                 'updatingGitHubUser': None
             }
         }
