@@ -7,7 +7,7 @@ from snapshottest import Snapshot
 
 snapshots = Snapshot()
 
-snapshots['test_schema_error[error-immutable-fields] 1'] = {
+snapshots['test_schema_error[error-constraint] 1'] = {
     'data': {
         'allProductFilePaths': {
             'edges': [
@@ -184,7 +184,12 @@ snapshots['test_schema_success[delete-paths] 1'] = {
                                     'name': 'date_produced',
                                     'type_': 'DATE'
                                 },
-                                'name': 'date_produced',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'date_produced',
+                                        'type_': 'DATE'
+                                    }
+                                },
                                 'value': '2020-02-01'
                             }
                         }
@@ -214,7 +219,12 @@ snapshots['test_schema_success[delete-paths] 1'] = {
                                     'name': 'contact',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'contact',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'contact',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': None
                             }
                         },
@@ -224,23 +234,24 @@ snapshots['test_schema_success[delete-paths] 1'] = {
                                     'name': 'produced_by',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'produced_by',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'produced_by',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': None
                             }
                         }
                     ]
                 },
-                'contact': None,
-                'dateProduced': '2020-02-01',
                 'name': 'map1',
                 'note': None,
                 'paths': {
                     'edges': [
                     ]
                 },
-                'postedBy': None,
                 'postingGitHubUser': None,
-                'producedBy': None,
                 'productId': '1',
                 'relations': {
                     'edges': [
@@ -311,7 +322,6 @@ snapshots['test_schema_success[delete-paths] 1'] = {
                     'name': 'map',
                     'typeId': '1'
                 },
-                'updatedBy': 'updater',
                 'updatingGitHubUser': {
                     'login': 'user1'
                 }
@@ -487,7 +497,12 @@ snapshots['test_schema_success[delete-relations] 1'] = {
                                     'name': 'date_produced',
                                     'type_': 'DATE'
                                 },
-                                'name': 'date_produced',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'date_produced',
+                                        'type_': 'DATE'
+                                    }
+                                },
                                 'value': '2020-03-04'
                             }
                         }
@@ -517,7 +532,12 @@ snapshots['test_schema_success[delete-relations] 1'] = {
                                     'name': 'contact',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'contact',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'contact',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': None
                             }
                         },
@@ -527,14 +547,17 @@ snapshots['test_schema_success[delete-relations] 1'] = {
                                     'name': 'produced_by',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'produced_by',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'produced_by',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': None
                             }
                         }
                     ]
                 },
-                'contact': None,
-                'dateProduced': '2020-03-04',
                 'name': 'beam2',
                 'note': None,
                 'paths': {
@@ -548,9 +571,7 @@ snapshots['test_schema_success[delete-relations] 1'] = {
                         }
                     ]
                 },
-                'postedBy': None,
                 'postingGitHubUser': None,
-                'producedBy': None,
                 'productId': '5',
                 'relations': {
                     'edges': [
@@ -563,7 +584,6 @@ snapshots['test_schema_success[delete-relations] 1'] = {
                     'name': 'beam',
                     'typeId': '2'
                 },
-                'updatedBy': 'updater',
                 'updatingGitHubUser': {
                     'login': 'user1'
                 }
@@ -680,7 +700,7 @@ snapshots['test_schema_success[delete-relations] 2'] = {
     }
 }
 
-snapshots['test_schema_success[update-paths] 1'] = {
+snapshots['test_schema_success[update-name] 1'] = {
     'data': {
         'updateProduct': {
             'ok': True,
@@ -697,7 +717,12 @@ snapshots['test_schema_success[update-paths] 1'] = {
                                     'name': 'date_produced',
                                     'type_': 'DATE'
                                 },
-                                'name': 'date_produced',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'date_produced',
+                                        'type_': 'DATE'
+                                    }
+                                },
                                 'value': '2020-02-01'
                             }
                         }
@@ -727,7 +752,12 @@ snapshots['test_schema_success[update-paths] 1'] = {
                                     'name': 'contact',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'contact',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'contact',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': None
                             }
                         },
@@ -737,15 +767,18 @@ snapshots['test_schema_success[update-paths] 1'] = {
                                     'name': 'produced_by',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'produced_by',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'produced_by',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': None
                             }
                         }
                     ]
                 },
-                'contact': None,
-                'dateProduced': '2020-02-01',
-                'name': 'map1',
+                'name': 'new-name',
                 'note': None,
                 'paths': {
                     'edges': [
@@ -759,6 +792,343 @@ snapshots['test_schema_success[update-paths] 1'] = {
                         {
                             'node': {
                                 'note': None,
+                                'path': 'site2:/another/way/map1',
+                                'pathId': '2'
+                            }
+                        }
+                    ]
+                },
+                'postingGitHubUser': None,
+                'productId': '1',
+                'relations': {
+                    'edges': [
+                        {
+                            'node': {
+                                'other': {
+                                    'name': 'beam1',
+                                    'productId': '4',
+                                    'typeId': 2,
+                                    'type_': {
+                                        'name': 'beam',
+                                        'typeId': '2'
+                                    }
+                                },
+                                'otherProductId': 4,
+                                'relationId': '1',
+                                'reverse': {
+                                    'relationId': '2',
+                                    'typeId': 1,
+                                    'type_': {
+                                        'name': 'parent',
+                                        'typeId': '1'
+                                    }
+                                },
+                                'reverseRelationId': 2,
+                                'typeId': 2,
+                                'type_': {
+                                    'name': 'child',
+                                    'typeId': '2'
+                                }
+                            }
+                        },
+                        {
+                            'node': {
+                                'other': {
+                                    'name': 'beam2',
+                                    'productId': '5',
+                                    'typeId': 2,
+                                    'type_': {
+                                        'name': 'beam',
+                                        'typeId': '2'
+                                    }
+                                },
+                                'otherProductId': 5,
+                                'relationId': '3',
+                                'reverse': {
+                                    'relationId': '4',
+                                    'typeId': 1,
+                                    'type_': {
+                                        'name': 'parent',
+                                        'typeId': '1'
+                                    }
+                                },
+                                'reverseRelationId': 4,
+                                'typeId': 2,
+                                'type_': {
+                                    'name': 'child',
+                                    'typeId': '2'
+                                }
+                            }
+                        }
+                    ]
+                },
+                'timePosted': '2021-01-04T14:32:20',
+                'timeUpdated': '2021-01-04T14:32:20',
+                'typeId': 1,
+                'type_': {
+                    'name': 'map',
+                    'typeId': '1'
+                },
+                'updatingGitHubUser': {
+                    'login': 'user1'
+                }
+            }
+        }
+    }
+}
+
+snapshots['test_schema_success[update-name] 2'] = {
+    'data': {
+        'allProductFilePaths': {
+            'edges': [
+                {
+                    'node': {
+                        'path': 'site1:/path/to/map1'
+                    }
+                },
+                {
+                    'node': {
+                        'path': 'site2:/another/way/map1'
+                    }
+                },
+                {
+                    'node': {
+                        'path': 'site1:/path/to/map2'
+                    }
+                },
+                {
+                    'node': {
+                        'path': 'site1:/path/to/map3'
+                    }
+                },
+                {
+                    'node': {
+                        'path': 'site2:/another/way/map3'
+                    }
+                },
+                {
+                    'node': {
+                        'path': 'site1:/path/to/beam1'
+                    }
+                },
+                {
+                    'node': {
+                        'path': 'site2:/another/way/beam1'
+                    }
+                },
+                {
+                    'node': {
+                        'path': 'site1:/path/to/beam2'
+                    }
+                }
+            ]
+        },
+        'allProductRelations': {
+            'edges': [
+                {
+                    'node': {
+                        'other': {
+                            'name': 'beam1'
+                        },
+                        'self_': {
+                            'name': 'new-name'
+                        },
+                        'type_': {
+                            'name': 'child'
+                        }
+                    }
+                },
+                {
+                    'node': {
+                        'other': {
+                            'name': 'new-name'
+                        },
+                        'self_': {
+                            'name': 'beam1'
+                        },
+                        'type_': {
+                            'name': 'parent'
+                        }
+                    }
+                },
+                {
+                    'node': {
+                        'other': {
+                            'name': 'beam2'
+                        },
+                        'self_': {
+                            'name': 'new-name'
+                        },
+                        'type_': {
+                            'name': 'child'
+                        }
+                    }
+                },
+                {
+                    'node': {
+                        'other': {
+                            'name': 'new-name'
+                        },
+                        'self_': {
+                            'name': 'beam2'
+                        },
+                        'type_': {
+                            'name': 'parent'
+                        }
+                    }
+                },
+                {
+                    'node': {
+                        'other': {
+                            'name': 'beam2'
+                        },
+                        'self_': {
+                            'name': 'beam1'
+                        },
+                        'type_': {
+                            'name': 'child'
+                        }
+                    }
+                },
+                {
+                    'node': {
+                        'other': {
+                            'name': 'beam1'
+                        },
+                        'self_': {
+                            'name': 'beam2'
+                        },
+                        'type_': {
+                            'name': 'parent'
+                        }
+                    }
+                }
+            ]
+        },
+        'allProducts': {
+            'edges': [
+                {
+                    'node': {
+                        'name': 'new-name'
+                    }
+                },
+                {
+                    'node': {
+                        'name': 'map2'
+                    }
+                },
+                {
+                    'node': {
+                        'name': 'map3'
+                    }
+                },
+                {
+                    'node': {
+                        'name': 'beam1'
+                    }
+                },
+                {
+                    'node': {
+                        'name': 'beam2'
+                    }
+                }
+            ]
+        }
+    }
+}
+
+snapshots['test_schema_success[update-paths] 1'] = {
+    'data': {
+        'updateProduct': {
+            'ok': True,
+            'product': {
+                'attributesBoolean': {
+                    'edges': [
+                    ]
+                },
+                'attributesDate': {
+                    'edges': [
+                        {
+                            'node': {
+                                'field': {
+                                    'name': 'date_produced',
+                                    'type_': 'DATE'
+                                },
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'date_produced',
+                                        'type_': 'DATE'
+                                    }
+                                },
+                                'value': '2020-02-01'
+                            }
+                        }
+                    ]
+                },
+                'attributesDateTime': {
+                    'edges': [
+                    ]
+                },
+                'attributesFloat': {
+                    'edges': [
+                    ]
+                },
+                'attributesInteger': {
+                    'edges': [
+                    ]
+                },
+                'attributesTime': {
+                    'edges': [
+                    ]
+                },
+                'attributesUnicodeText': {
+                    'edges': [
+                        {
+                            'node': {
+                                'field': {
+                                    'name': 'contact',
+                                    'type_': 'UNICODE_TEXT'
+                                },
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'contact',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
+                                'value': None
+                            }
+                        },
+                        {
+                            'node': {
+                                'field': {
+                                    'name': 'produced_by',
+                                    'type_': 'UNICODE_TEXT'
+                                },
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'produced_by',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
+                                'value': None
+                            }
+                        }
+                    ]
+                },
+                'name': 'map1',
+                'note': None,
+                'paths': {
+                    'edges': [
+                        {
+                            'node': {
+                                'note': None,
+                                'path': 'site1:/path/to/map1',
+                                'pathId': '1'
+                            }
+                        },
+                        {
+                            'node': {
+                                'note': None,
                                 'path': 'site2:/updated/way/map1',
                                 'pathId': '9'
                             }
@@ -772,9 +1142,7 @@ snapshots['test_schema_success[update-paths] 1'] = {
                         }
                     ]
                 },
-                'postedBy': None,
                 'postingGitHubUser': None,
-                'producedBy': None,
                 'productId': '1',
                 'relations': {
                     'edges': [
@@ -845,7 +1213,6 @@ snapshots['test_schema_success[update-paths] 1'] = {
                     'name': 'map',
                     'typeId': '1'
                 },
-                'updatedBy': 'updater',
                 'updatingGitHubUser': {
                     'login': 'user1'
                 }
@@ -1036,7 +1403,12 @@ snapshots['test_schema_success[update-relations] 1'] = {
                                     'name': 'date_produced',
                                     'type_': 'DATE'
                                 },
-                                'name': 'date_produced',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'date_produced',
+                                        'type_': 'DATE'
+                                    }
+                                },
                                 'value': '2020-03-04'
                             }
                         }
@@ -1066,7 +1438,12 @@ snapshots['test_schema_success[update-relations] 1'] = {
                                     'name': 'contact',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'contact',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'contact',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': None
                             }
                         },
@@ -1076,14 +1453,17 @@ snapshots['test_schema_success[update-relations] 1'] = {
                                     'name': 'produced_by',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'produced_by',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'produced_by',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': None
                             }
                         }
                     ]
                 },
-                'contact': None,
-                'dateProduced': '2020-03-04',
                 'name': 'beam2',
                 'note': None,
                 'paths': {
@@ -1097,9 +1477,7 @@ snapshots['test_schema_success[update-relations] 1'] = {
                         }
                     ]
                 },
-                'postedBy': None,
                 'postingGitHubUser': None,
-                'producedBy': None,
                 'productId': '5',
                 'relations': {
                     'edges': [
@@ -1170,7 +1548,6 @@ snapshots['test_schema_success[update-relations] 1'] = {
                     'name': 'beam',
                     'typeId': '2'
                 },
-                'updatedBy': 'updater',
                 'updatingGitHubUser': {
                     'login': 'user1'
                 }
@@ -1356,7 +1733,12 @@ snapshots['test_schema_success[update] 1'] = {
                                     'name': 'date_produced',
                                     'type_': 'DATE'
                                 },
-                                'name': 'date_produced',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'date_produced',
+                                        'type_': 'DATE'
+                                    }
+                                },
                                 'value': '2020-02-01'
                             }
                         }
@@ -1386,7 +1768,12 @@ snapshots['test_schema_success[update] 1'] = {
                                     'name': 'contact',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'contact',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'contact',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': 'new-contact'
                             }
                         },
@@ -1396,14 +1783,17 @@ snapshots['test_schema_success[update] 1'] = {
                                     'name': 'produced_by',
                                     'type_': 'UNICODE_TEXT'
                                 },
-                                'name': 'produced_by',
+                                'typeFieldAssociation': {
+                                    'field': {
+                                        'name': 'produced_by',
+                                        'type_': 'UNICODE_TEXT'
+                                    }
+                                },
                                 'value': None
                             }
                         }
                     ]
                 },
-                'contact': 'new-contact',
-                'dateProduced': '2020-02-01',
                 'name': 'map1',
                 'note': '- updated note 123',
                 'paths': {
@@ -1424,9 +1814,7 @@ snapshots['test_schema_success[update] 1'] = {
                         }
                     ]
                 },
-                'postedBy': None,
                 'postingGitHubUser': None,
-                'producedBy': None,
                 'productId': '1',
                 'relations': {
                     'edges': [
@@ -1497,7 +1885,6 @@ snapshots['test_schema_success[update] 1'] = {
                     'name': 'map',
                     'typeId': '1'
                 },
-                'updatedBy': 'updater',
                 'updatingGitHubUser': {
                     'login': 'user1'
                 }
