@@ -25,7 +25,12 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'date_produced',
                                             'type_': 'DATE'
                                         },
-                                        'name': 'date_produced',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'date_produced',
+                                                'type_': 'DATE'
+                                            }
+                                        },
                                         'value': '2020-02-01'
                                     }
                                 }
@@ -55,7 +60,12 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'contact',
                                             'type_': 'UNICODE_TEXT'
                                         },
-                                        'name': 'contact',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'contact',
+                                                'type_': 'UNICODE_TEXT'
+                                            }
+                                        },
                                         'value': None
                                     }
                                 },
@@ -65,14 +75,17 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'produced_by',
                                             'type_': 'UNICODE_TEXT'
                                         },
-                                        'name': 'produced_by',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'produced_by',
+                                                'type_': 'UNICODE_TEXT'
+                                            }
+                                        },
                                         'value': None
                                     }
                                 }
                             ]
                         },
-                        'contact': None,
-                        'dateProduced': '2020-02-01',
                         'name': 'map1',
                         'note': None,
                         'paths': {
@@ -93,9 +106,7 @@ snapshots['test_schema[deep] 1'] = {
                                 }
                             ]
                         },
-                        'postedBy': None,
                         'postingGitHubUser': None,
-                        'producedBy': None,
                         'productId': '1',
                         'relations': {
                             'edges': [
@@ -166,7 +177,6 @@ snapshots['test_schema[deep] 1'] = {
                             'name': 'map',
                             'typeId': '1'
                         },
-                        'updatedBy': None,
                         'updatingGitHubUser': None
                     }
                 },
@@ -184,7 +194,12 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'date_produced',
                                             'type_': 'DATE'
                                         },
-                                        'name': 'date_produced',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'date_produced',
+                                                'type_': 'DATE'
+                                            }
+                                        },
                                         'value': '2020-02-10'
                                     }
                                 }
@@ -214,7 +229,12 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'contact',
                                             'type_': 'UNICODE_TEXT'
                                         },
-                                        'name': 'contact',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'contact',
+                                                'type_': 'UNICODE_TEXT'
+                                            }
+                                        },
                                         'value': None
                                     }
                                 },
@@ -224,14 +244,17 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'produced_by',
                                             'type_': 'UNICODE_TEXT'
                                         },
-                                        'name': 'produced_by',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'produced_by',
+                                                'type_': 'UNICODE_TEXT'
+                                            }
+                                        },
                                         'value': None
                                     }
                                 }
                             ]
                         },
-                        'contact': None,
-                        'dateProduced': '2020-02-10',
                         'name': 'map2',
                         'note': None,
                         'paths': {
@@ -245,9 +268,7 @@ snapshots['test_schema[deep] 1'] = {
                                 }
                             ]
                         },
-                        'postedBy': None,
                         'postingGitHubUser': None,
-                        'producedBy': None,
                         'productId': '2',
                         'relations': {
                             'edges': [
@@ -260,7 +281,6 @@ snapshots['test_schema[deep] 1'] = {
                             'name': 'map',
                             'typeId': '1'
                         },
-                        'updatedBy': None,
                         'updatingGitHubUser': None
                     }
                 },
@@ -278,7 +298,12 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'date_produced',
                                             'type_': 'DATE'
                                         },
-                                        'name': 'date_produced',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'date_produced',
+                                                'type_': 'DATE'
+                                            }
+                                        },
                                         'value': '2020-03-19'
                                     }
                                 }
@@ -308,7 +333,12 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'contact',
                                             'type_': 'UNICODE_TEXT'
                                         },
-                                        'name': 'contact',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'contact',
+                                                'type_': 'UNICODE_TEXT'
+                                            }
+                                        },
                                         'value': None
                                     }
                                 },
@@ -318,14 +348,17 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'produced_by',
                                             'type_': 'UNICODE_TEXT'
                                         },
-                                        'name': 'produced_by',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'produced_by',
+                                                'type_': 'UNICODE_TEXT'
+                                            }
+                                        },
                                         'value': None
                                     }
                                 }
                             ]
                         },
-                        'contact': None,
-                        'dateProduced': '2020-03-19',
                         'name': 'map3',
                         'note': None,
                         'paths': {
@@ -346,9 +379,7 @@ snapshots['test_schema[deep] 1'] = {
                                 }
                             ]
                         },
-                        'postedBy': None,
                         'postingGitHubUser': None,
-                        'producedBy': None,
                         'productId': '3',
                         'relations': {
                             'edges': [
@@ -361,7 +392,6 @@ snapshots['test_schema[deep] 1'] = {
                             'name': 'map',
                             'typeId': '1'
                         },
-                        'updatedBy': None,
                         'updatingGitHubUser': None
                     }
                 },
@@ -379,7 +409,12 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'date_produced',
                                             'type_': 'DATE'
                                         },
-                                        'name': 'date_produced',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'date_produced',
+                                                'type_': 'DATE'
+                                            }
+                                        },
                                         'value': '2020-02-05'
                                     }
                                 }
@@ -409,7 +444,12 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'contact',
                                             'type_': 'UNICODE_TEXT'
                                         },
-                                        'name': 'contact',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'contact',
+                                                'type_': 'UNICODE_TEXT'
+                                            }
+                                        },
                                         'value': None
                                     }
                                 },
@@ -419,14 +459,17 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'produced_by',
                                             'type_': 'UNICODE_TEXT'
                                         },
-                                        'name': 'produced_by',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'produced_by',
+                                                'type_': 'UNICODE_TEXT'
+                                            }
+                                        },
                                         'value': None
                                     }
                                 }
                             ]
                         },
-                        'contact': None,
-                        'dateProduced': '2020-02-05',
                         'name': 'beam1',
                         'note': None,
                         'paths': {
@@ -447,9 +490,7 @@ snapshots['test_schema[deep] 1'] = {
                                 }
                             ]
                         },
-                        'postedBy': None,
                         'postingGitHubUser': None,
-                        'producedBy': None,
                         'productId': '4',
                         'relations': {
                             'edges': [
@@ -520,7 +561,6 @@ snapshots['test_schema[deep] 1'] = {
                             'name': 'beam',
                             'typeId': '2'
                         },
-                        'updatedBy': None,
                         'updatingGitHubUser': None
                     }
                 },
@@ -538,7 +578,12 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'date_produced',
                                             'type_': 'DATE'
                                         },
-                                        'name': 'date_produced',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'date_produced',
+                                                'type_': 'DATE'
+                                            }
+                                        },
                                         'value': '2020-03-04'
                                     }
                                 }
@@ -568,7 +613,12 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'contact',
                                             'type_': 'UNICODE_TEXT'
                                         },
-                                        'name': 'contact',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'contact',
+                                                'type_': 'UNICODE_TEXT'
+                                            }
+                                        },
                                         'value': None
                                     }
                                 },
@@ -578,14 +628,17 @@ snapshots['test_schema[deep] 1'] = {
                                             'name': 'produced_by',
                                             'type_': 'UNICODE_TEXT'
                                         },
-                                        'name': 'produced_by',
+                                        'typeFieldAssociation': {
+                                            'field': {
+                                                'name': 'produced_by',
+                                                'type_': 'UNICODE_TEXT'
+                                            }
+                                        },
                                         'value': None
                                     }
                                 }
                             ]
                         },
-                        'contact': None,
-                        'dateProduced': '2020-03-04',
                         'name': 'beam2',
                         'note': None,
                         'paths': {
@@ -599,9 +652,7 @@ snapshots['test_schema[deep] 1'] = {
                                 }
                             ]
                         },
-                        'postedBy': None,
                         'postingGitHubUser': None,
-                        'producedBy': None,
                         'productId': '5',
                         'relations': {
                             'edges': [
@@ -672,7 +723,6 @@ snapshots['test_schema[deep] 1'] = {
                             'name': 'beam',
                             'typeId': '2'
                         },
-                        'updatedBy': None,
                         'updatingGitHubUser': None
                     }
                 }
@@ -710,8 +760,8 @@ snapshots['test_schema[filters-type_id-sort] 1'] = {
             'edges': [
                 {
                     'node': {
-                        'name': 'map3',
-                        'productId': '3',
+                        'name': 'map1',
+                        'productId': '1',
                         'typeId': 1
                     }
                 },
@@ -724,8 +774,8 @@ snapshots['test_schema[filters-type_id-sort] 1'] = {
                 },
                 {
                     'node': {
-                        'name': 'map1',
-                        'productId': '1',
+                        'name': 'map3',
+                        'productId': '3',
                         'typeId': 1
                     }
                 }
@@ -763,8 +813,8 @@ snapshots['test_schema[filters-type_name-sort] 1'] = {
             'edges': [
                 {
                     'node': {
-                        'name': 'map3',
-                        'productId': '3',
+                        'name': 'map1',
+                        'productId': '1',
                         'typeId': 1
                     }
                 },
@@ -777,8 +827,8 @@ snapshots['test_schema[filters-type_name-sort] 1'] = {
                 },
                 {
                     'node': {
-                        'name': 'map1',
-                        'productId': '1',
+                        'name': 'map3',
+                        'productId': '3',
                         'typeId': 1
                     }
                 }
@@ -793,16 +843,16 @@ snapshots['test_schema[first-two-sort] 1'] = {
             'edges': [
                 {
                     'node': {
-                        'name': 'map3',
-                        'productId': '3',
+                        'name': 'map1',
+                        'productId': '1',
                         'typeId': 1
                     }
                 },
                 {
                     'node': {
-                        'name': 'beam2',
-                        'productId': '5',
-                        'typeId': 2
+                        'name': 'map2',
+                        'productId': '2',
+                        'typeId': 1
                     }
                 }
             ]
